@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-#   Copyright 2013 Hewlett-Packard Development Company, L.P.
+#   Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,5 +14,6 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from hpsdnclient.api import __version__, Api
-from hpsdnclient.auth import XAuthToken
\ No newline at end of file
+from hpsdnclient.api import Api
+from hpsdnclient.auth import XAuthToken
+from hpsdnclient.version import __version__
